<?php
require_once("dbconn.php");
require_once("phpFunctions.php");

$ProductionDate = isset($_SESSION["ProductionDate"]) ? $_SESSION["ProductionDate"] : date("Y-m-d");
$headers = [
"id", 
"Production Date", 
"Batch Name", 
"Age", 
"S.H.D.%", 
"S.H.H", 
"A.H.D.%", 
"A.H.H.", 
"Liv %",
"Bad Eggs"
];

echo "<table id='GraphTable' class='ui display hidden' style='display: none;'>";
echo "<thead><tr>";
foreach ($headers as $header) {
    echo "<th>".$header."</th>";
}
echo "</tr></thead><tbody>";

$query = "SELECT 
	ip.id, 
	ip.BatchName, 
	ip.AgeInWeeks, 
	ip.ProductionDate,
	COALESCE(SUM(ip.H_TOTAL), 0) as HenDayTotal, 
	COALESCE(SUM(ip.Hen_Day), 0) as Pop,
	ebd.Breed,
	ebd.Prod_Previous,
	(SELECT COALESCE(SUM(Stnd_H_D_per), 0) FROM controller_standards cs WHERE cs.is_current = TRUE AND cs.BreedType = ebd.Breed AND cs.AgeInWeeks = ip.AgeInWeeks LIMIT 1) as SHD_Total,
	(SELECT Stnd_H_H_per FROM controller_standards cs WHERE cs.is_current = TRUE AND cs.BreedType = ebd.Breed AND cs.AgeInWeeks = ip.AgeInWeeks LIMIT 1) as Stnd_H_H_per,
	(SELECT HenHoused FROM epr_batch_details hh WHERE hh.is_current = TRUE AND hh.BatchName = ip.BatchName LIMIT 1) as HenHoused,
	(SELECT COALESCE(SUM(HenHoused), 0) FROM epr_batch_details liv WHERE liv.is_current = TRUE AND liv.BatchName = ip.BatchName LIMIT 1) as TotalHenHoused,
	(SELECT COALESCE(SUM(B1 + B2 + B3), 0) FROM egg_weight ew WHERE ew.BatchName = ip.BatchName AND ew.ProductionDate = ip.ProductionDate) as Crack
  FROM input_production ip
  LEFT JOIN epr_batch_details ebd ON ip.BatchName = ebd.BatchName AND ebd.is_current = TRUE
  WHERE ip.is_current = TRUE
  GROUP BY ip.BatchName, ip.ProductionDate ORDER BY ProductionDate";

$result = executeQuery($conn, $query);

if ($result === false) { 
	throw new Exception("Error executing query: " . $conn->error);
} 

while ($row = mysqli_fetch_assoc($result)) 
{
    echo "<tr>";
    echo "<td>".$row["id"]."</td>";
	echo "<td>".$row["ProductionDate"]."</td>";
	echo "<td>".$row["BatchName"]."</td>";
	echo "<td>".$row["AgeInWeeks"]."</td>";
	
	$SHD_PER = !empty($row["SHD_Total"]) ? $row["SHD_Total"] : 0;
    echo "<td>" . number_format($SHD_PER, 2) . "%</td>";
    
	$SHH = !empty($row["Stnd_H_H_per"]) ? $row["Stnd_H_H_per"] : 0;
    echo "<td>" . number_format($SHH, 2) . "</td>";
	
	// AHD Calculation
    if (!empty($row["HenDayTotal"]) && !empty($row["Pop"])) {
        $AHD = ($row["HenDayTotal"] / $row["Pop"]) * 100;
    } else {
        $AHD = 0;
    }
    echo "<td>" . number_format($AHD, 2) . "%</td>";
	
	$startDate = "2024-08-01";
	$endDate = $ProductionDate; // Example end date
	
	$rrquery = "SELECT COALESCE(SUM(H_TOTAL), 0) as Prod_Current 
            FROM input_production 
            WHERE BatchName = ? 
            AND ProductionDate >= ? 
            AND ProductionDate <= ?
			AND is_current = TRUE";
	$rresult = executeQuery($conn, $rrquery, "sss", [$row["BatchName"], $startDate, $endDate]);
	
	if ($rresult === false) { 
		throw new Exception("Error executing query: " . $conn->error);
	} 

	$rrow = mysqli_fetch_assoc($rresult);

	$Prod_YTD = $rrow["Prod_Current"] + $row["Prod_Previous"];
	
	// A.H.H. Block
    $AHH_TOTAL = 0;
    if (!empty($row["HenHoused"]) && !empty($Prod_YTD)) {
        $AHH_TOTAL = $Prod_YTD / $row["HenHoused"];
    }
    echo "<td>" . ($AHH_TOTAL == 0 ? "" : number_format($AHH_TOTAL, 2)) . "</td>";
	
	// Liv % Block
    if (!empty($row["Pop"]) && !empty($row["TotalHenHoused"])) {
        $LIV_PER = ($row["Pop"] / $row["TotalHenHoused"]) * 100;
    } else {
        $LIV_PER = 0;
    }
    echo "<td>" . number_format($LIV_PER, 2) . "%</td>";
	
	echo "<td>" . $row["Crack"] . "</td>";
	
	echo "</tr>";
}
echo "</tbody></table>";
?>